#
# spec file for package ccache
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           ccache
Version:        3.4.2
Release:        lp150.1.1
Summary:        A Fast C/C++ Compiler Cache
License:        GPL-3.0-or-later
Group:          Development/Languages/C and C++
Url:            https://ccache.samba.org/
Source0:        https://www.samba.org/ftp/%{name}/%{name}-%{version}.tar.xz
Source1:        https://www.samba.org/ftp/%{name}/%{name}-%{version}.tar.xz.asc
Source2:        %{name}.keyring
BuildRequires:  xz
BuildRequires:  zlib-devel
Provides:       distcc:%{_bindir}/ccache

%description
ccache is a compiler cache. It speeds up recompilation by caching the
result of previous compilations and detecting when the same compilation is
being done again. Supported languages are C, C++, Objective-C and
Objective-C++.

%prep
%autosetup

%build
%configure
make %{?_smp_mflags}

%install
%make_install

# create the compat symlinks into /usr/libdir/ccache
mkdir -p %{buildroot}/%{_libdir}/%{name}
cd %{buildroot}/%{_libdir}/%{name}
ln -sf ../../bin/%{name} gcc
ln -sf ../../bin/%{name} g++
ln -sf ../../bin/%{name} gcc-objc
ln -sf ../../bin/%{name} gfortran
# do the same for clang
ln -sf ../../bin/%{name} clang
ln -sf ../../bin/%{name} clang++
# and regular cc
ln -sf ../../bin/%{name} cc
ln -sf ../../bin/%{name} c++

%files
%license LICENSE.* GPL-3.0.txt
%doc doc/AUTHORS.* doc/MANUAL.* doc/NEWS.* README.*
%{_bindir}/%{name}
%{_libdir}/%{name}
%{_mandir}/man1/%{name}.1%{?ext_man}

%changelog
* Tue Apr 17 2018 kstreitova@suse.com
- Update to version 3.4.2 [bsc#1089879]
  * The cleanup algorithm has been fixed to not misbehave when
    files are removed by another process while the cleanup process
    is running. Previously, too many files could be removed from
    the cache if multiple cleanup processes were triggered at the
    same time, in extreme cases trimming the cache to a much
    smaller size than the configured limits.
  * Correctly hash preprocessed headers located in a
    “.gch directory”. Previously, ccache would not pick up changes
    to such precompiled headers, risking false positive cache hits.
  * Fixed build failure when using the bundled zlib sources.
  * ccache 3.3.5 added a workaround for not triggering Clang errors
    when a precompiled header’s dependency has an updated timestamp
    (but identical content). That workaround is now only applied
    when the compiler is Clang.
  * Made it possible to perform out-of-source builds in dev mode
    again.
- AUTHORS.*, MANUAL.* and NEWS.* files are now located in the doc
  directory
* Thu Mar 15 2018 mpluskal@suse.com
- Update to version 3.4.1:
  * Fixed printing of version number in ccache --version.
- Changes for version 3.4.0:
  * The compiler option form --sysroot arg is now handled like the
    documented --sysroot=arg form.
  * Added support for caching .su files generated by GCC flag
  - fstack-usage.
  * ccache should now work with distcc’s “pump” wrapper.
  * The optional unifier is no longer disabled when the direct mode
    is enabled.
  * Added support for nvcc compiler options --compiler-bindir/-ccbin,
  - -output-directory/-odir and --libdevice-directory/-ldir.
  * Boolean environment variable settings no longer accept the
    following (case-insensitive) values: 0, false, disable and no.
    All other values are accepted and taken to mean “true”. This is
    to stop users from setting e.g. CCACHE_DISABLE=0 and then
    expect the cache to be used.
  * Improved support for run_second_cpp = false: If combined with
    passing -fdirectives-only (GCC) or frewrite-includes (Clang) to
    the compiler, diagnostics warnings and similar will be correct.
  * An implicit -MQ is now passed to the preprocessor only if the
    object file extension is non-standard. This should make it
    easier to use EDG-based compilers (e.g. GHS) which don’t
    understand -MQ.
  * ccache now treats an unreadable configuration file just like a
    missing configuration file.
  * Documented more pitfalls with enabling hard_links
    (CCACHE_HARDLINK).
  * Documented caveats related to colored warnings from compilers.
  * File size and number counters are now updated correctly when
    files are overwritten in the cache, e.g. when using
    CCACHE_RECACHE.
  * run_second_cpp is now forced for nvcc.
  * Fixed how the nvcc options -optf and -odir are handled.
* Sat Feb  3 2018 avindra@opensuse.org
- Update to version 3.3.6:
  * Improved instructions on how to get cache hits between different
    working directories.
- Changes for version 3.3.5:
  * Documented how automatic cache cleanup works.
  * Fixed a regression where the original order of debug options
    could be lost. This reverts the “Improved parsing of -g*
    options” feature in ccache 3.3.
  * Multiple -fdebug-prefix-map options should now be handled
    correctly.
  * Fixed matching of directories in the ignore_headers_in_manifest
    configuration option.
  * Fixed detection of missing argument to -opt/--options-file.
  * ccache now bails out when building a precompiled header if any
    of the corresponding header files have an updated timestamp.
    This fixes complaints from clang.
  * Fixed a bug related to erroneously storing a dependency file
    with absolute paths in the cache on a preprocessed hit.
  * ccache -c/--cleanup now works like documented: it just
    recalculates size counters and trims the cache to not exceed
    the max size and file number limits. Previously, the forced
    cleanup took “limit_multiple” into account, so that ccache
  - c/--cleanup by default would trim the cache to 80%% of the max
    limit.
  * ccache no longer ignores linker arguments for clang since clang
    warns about them.
  * Plugged a couple of file descriptor leaks.
  * Fixed a bug where ccache would skip hashing the compiler
    argument following a -fno-working-directory,
  - fworking-directory, -nostdinc, -nostdinc++, -remap or
  - trigraphs option in preprocessor mode.
- cleanup with spec-cleaner
* Wed Apr  5 2017 mpluskal@suse.com
- Update to version 3.3.4:
  * Documented the different cache statistics counters.
  * Fixed a regression in ccache 3.3 related to potentially bad
    content of dependency files when compiling identical source
    code but with different source paths. This was only partially
    fixed in 3.3.2 and reverts the new “Names of included files are
    no longer included in the hash of the compiler’s preprocessed
    output” feature in 3.3.
  * Corrected statistics counter for -optf/--options-file failure.
  * Fixed undefined behavior warnings in ccache found by
  - fsanitize=undefined.
* Thu Jan 19 2017 asn@cryptomilk.org
- Update to version 3.3.3
  * ccache now detects usage of .incbin assembler directives in
    the source code and avoids caching such compilations.
- Changes for version 3.3.2:
  * Fixed a regression in ccache 3.3 related to potentially bad
    content of dependency files when compiling identical source
    code but with different source paths.
  * Fixed a regression in ccache 3.3.1: ccache could get confused
    when using the compiler option -Wp, to pass multiple options
    to the preprocessor, resulting in missing dependency files
    from direct mode cache hits.
* Sun Sep 11 2016 mpluskal@suse.com
- Update to version 3.3.1:
  * Fixed a problem in the “multiple -arch options” support
    introduced in 3.3. When using the direct mode (the default),
    different combinations of -arch options were not detected
    properly.
  * Fixed an issue when compiler option -Wp,-MT,path is used
    instead of -MT path (and similar for -MF, -MP and -MQ) and
    run_second_cpp (CCACHE_CPP2) is enabled.
- Changes for version 3.3.0:
  * A C99-compatible compiler is now required to build ccache.
  * The configuration option run_second_cpp (CCACHE_CPP2) now
    defaults to true. This improves ccache’s out-of-the-box
    experience for compilers that can’t compile their own
    preprocessed output with the same outcome as if they compiled
    the real source code directly, e.g. newer versions of GCC and
    Clang.
  * The configuration option hash_dir (CCACHE_HASHDIR) now defaults
    to true.
  * Added a new ignore_headers_in_manifest configuration option,
    which specifies headers that should be ignored in the direct
    mode.
  * Added a new prefix_command_cpp (CCACHE_PREFIX_CPP) configuration
    option, which specifies one or several prefixes to add to the
    command line ccache uses when invoking the preprocessor.
  * Added a new limit_multiple (CCACHE_LIMIT_MULTIPLE) configuration
    option, which specifies how much of the cache to remove when
    cleaning.
  * Added a new keep_comments_cpp (CCACHE_COMMENTS) configuration
    option, which tells ccache not to discard the comments before
    hashing preprocessor output. This can be used to check
    documentation with -Wdocumentation.
  * Added a new sloppiness option no_system_headers, which tells
    ccache not to include system headers in manifest files.
  * Added a new statistics counter that tracks the number of
    performed cleanups due to the cache size being over the limit.
    The value is shown in the output of “ccache -s”.
  * Added support for relocating debug info directory using
  - fdebug-prefix-map. This allows for cache hits even when
    hash_dir is used in combination with base_dir.
  * Added a new “cache hit rate” field to the output of “ccache -s”.
  * Added support for caching compilation of assembler code produced
    by e.g. “gcc -S file.c”.
  * Added support for cuda including the -optf/--options-file option.
  * Added support for Fortran 77.
  * Added support for multiple -arch options to produce "fat binaries".
  * Multiple identical -arch arguments are now handled without bailing.
  * The concatenated form of some long compiler options is now
    recognized, for example when using -isystemPATH instead of
  - isystem PATH.
  * If hard-linking is enabled and but fails (e.g. due to
    cross-device linking), ccache now falls back to copying instead
    of running the compiler.
  * Made the hash_dir option only have effect when generating debug
    info.
  * ccache now knows how to convert absolute paths to relative
    paths inside dependency files when using base_dir.
  * Improved parsing of -g* options.
  * Made ccache understand -Wp,-D* options.
  * ccache now understands the undocumented -coverage (only one
    dash) GCC option.
  * Names of included files are no longer included in the hash of
    the compiler’s preprocessed output. This leads to more
    potential cache hits when not using the direct mode.
  * Increased buffer size used when reading file data. This
    improves performance slightly.
- Changes for version 3.2.8:
  * Bail out on too hard compiler option -P.
  * Fixed clang test suite when running on Linux.
  * Fixed build and test for MinGW32 and Windows.
- Add fortran amd objc symlinks
* Fri Aug 26 2016 tchvatal@suse.com
- Version update to 3.2.7:
  - Fixed build problem on QNX, which lacks ``SA_RESTART''.
  - Bail out on compiler option `-fstack-usage` since it creates a `.su` file
    which ccache currently doesn't handle.
  - Fixed a bug where (due to ccache rewriting paths) the compiler could choose
    incorrect include files if `CCACHE_BASEDIR` is used and the source file path
    is absolute and is a symlink.
  - Fixed a bug which could lead to false cache hits for compiler command lines
    with a missing argument to an option that takes an argument.
  - ccache now knows how to work around a glitch in the output of GCC 6's
    preprocessor.
* Fri Aug 26 2016 tchvatal@suse.com
- Create basic symlinks for clang and regular cc calls for ccache
  * this makes it easier to use ccache with osc build
* Fri Jul  8 2016 mpluskal@suse.com
- Small spec file cleanup
- Disable testsuite as it is not reliable in OBS
* Thu Apr 28 2016 idonmez@suse.com
- Update to 3.2.5
  * Only pass clang-specific -stdlib= to the preprocessor.
  * Improved handling of stale NFS handles.
  * Made it harder to misinterpret documentation of boolean
    environment settings' semantics.
  * Corrected "Performance" section in the manual regarding __DATE_,
    __TIME__ and __FILE__ macros.
  * Don’t (try to) update manifest file in “read-only” and
    “read-only direct” modes.
  * Fixed a bug in caching of stat system calls in “file_stat_matches
    sloppiness mode”.
  * Fixed bug in hashing of clang plugins, leading to unnecessary
    cache misses.
  * Fixed --print-config to show “pch_defines sloppiness”.
* Thu Oct  8 2015 mpluskal@suse.com
- Update to 3.2.4
  * Fixed build error related to zlib on systems with older make
    versions (regression in ccache 3.2.3).
  * Made conversion-to-bool explicit to avoid build warnings (and
    potential runtime errors) on legacy systems.
  * Improved signal handling: Kill compiler on SIGTERM; wait for
    compiler to exit before exiting; die appropriately.
  * Minor fixes related to Windows support.
  * The correct compression level is now used if compression is
    requested.
  * Fixed a bug where cache cleanup could be run too early for
    caches larger than 64 GiB on 32-bit systems.
* Sat Aug 22 2015 astieger@suse.com
- update to 3.2.3:
  * Added support for compiler option -gsplit-dwarf.
  * Support external zlib in nonstandard directory.
  * Avoid calling exit() inside an exit handler.
  * Let exit handler terminate properly.
  * Bail out on compiler option --save-temps in addition to
  - save-temps.
  * Only log "Disabling direct mode" once when failing to read
    potential include files.
* Fri May 22 2015 mpluskal@suse.com
- Update to 3.2.2
  * Added support for `CCACHE_COMPILERCHECK=string:<value>`. This
    is a faster alternative to `CCACHE_COMPILERCHECK=<command>` if
    the command's output can be precalculated by the build system.
  * Add support for caching code coverage results (compiling for
    gcov).
  * Fixed bug which could result in false cache hits when source
    code contains `'"'` followed by `" /*"` or `" //"` (with
    variations).
  * Made hash of cached result created with and without
    `CCACHE_CPP2` different. This makes it possible to rebuild
    with `CCACHE_CPP2` set without having to clear the cache to
    get new results.
  * Don't try to reset a non-existing stats file. This avoids
    ``No such file or directory'' messages in the ccache log when
    the cache directory doesn't exist.
  * Fixed a bug where ccache deleted clang diagnostics after
    compiler failures.
  * Avoid performing an unnecessary copy of the object file on a
    cache miss.
  * Bail out on too hard compiler option `-fmodules`.
  * Bail out on too hard compiler option `-fplugin=libcc1plugin`
    (interaction with GDB).
  * Fixed build error when compiling ccache with recent clang
    versions.
  * Removed signal-unsafe code from signal handler.
  * Corrected logic for when to output cached stderr.
  * Wipe the whole cached result on failure retrieving a cached
    file.
  * Fixed build error when compiling ccache with recent clang
    versions.
* Fri May 15 2015 mvyskocil@opensuse.org
- Add the compat symlinks for gcc/g++ to libdir, so prepending
  libdir to PATH enabled ccache by default
* Fri Feb 20 2015 mpluskal@suse.com
- Add gpg signature
- Remove ccache-gcc48.patch and xclang.patch (both are already
  present in current release)
- On i586, use only small testsuite (quicktest) full testsuite
  fails (https://bugzilla.samba.org/show_bug.cgi?id=11109)
- Update to 3.2.1:
  * Added support for configuring ccache via one or several
    configuration files instead of via environment variables.
    Environment variables still have priority but are no longer
    the recommended way of customizing ccache behavior. See the
    manual for more information.
  * Added support for compiler error/warning messages with color.
  * Made creation of temporary directories and cache directories
    smarter to avoid unnecessary stat calls.
  * Improved efficiency of the algorithm that scans for
    __DATE_ and __TIME__ tokens in the hashed source code.
  * Added support for several binaries (separated by space) in
    CCACHE_PREFIX.
  * The -c option is no longer passed to the preprocessor.
    This fixes problems with clang and Solaris’s C++ compiler.
  * ccache no longer passes preprocessor options like -D and -I to
    the compiler when compiling preprocessed output. This fixes
    warnings emitted by clang.
  * Compiler options -fprofile-generate, -fprofile-arcs,
  - fprofile-use and -fbranch-probabilities are now handled
    without bailing.
  * Added support for clang’s --serialize-diagnostic option,
    storing the diagnostic file (.dia) in the cache.
  * Added support for precompiled headers when using clang.
  * Changed the -x language option to use the new objective C
    standard for GCC and clang.
  * On a cache miss, ccache now instructs the compiler to create
    the object file at the real destination and then copies the
    file into the cache instead of the other way around. This is
    needed to support compiler options like -fprofile-arcs
    and --serialize-diagnostics.
  * ccache now checks that included files' ctimes aren’t too new.
    This check can be turned off by adding include_file_ctime
    to the “ccache sloppinessâhe filename part of options
    like -Wp,-MDfilename is no longer included in the hash
    since the filename doesn’t have any bearing on the result.
  * Added a “read-only directâefault cache size is now 5 GB
    (was previously 1 GiB).
  * Added support for @file and -@file arguments (reading options
    from a file).
  * Bail out on too hard compiler option -Wp,-P.
  * Optimized MD4 calculation code on little-endian systems.
  * Various improvements and fixes on win32.
  * Improved logging to the ccache log file.
  * Added --dump-manifest command-line option for debugging purposes.
  * Added --with-bundled-zlib configure option.
  * Upgraded bundled zlib to version 1.2.8.
  * Improved dev.mk to be more platform independent.
  * Made the test suite work with clang and gcc-llvm on OS X.
  * Various other improvements of the test suite.
* Tue Jun 25 2013 pgajdos@suse.com
- fixed build with gcc 4.8
  * ccache-gcc48.patch
* Sat Feb 23 2013 asterios.dramis@gmail.com
- Update to 3.1.9:
  - The EAGAIN signal is now handled correctly when emitting cached stderr
    output. This fixes a problem triggered by large error outputs from the
    compiler.
  - Subdirectories in the cache are no longer created in read-only mode.
  - Fixed so that ccache's log file descriptor is not made available to the
    compiler.
  - Improved error reporting when failing to create temporary stdout/stderr
    files when executing the compiler.
  - Disappearing temporary stdout/stderr files are now handled gracefully.
  - Fixed test suite to work on ecryptfs.
* Fri Jan  4 2013 llunak@suse.com
- Add xclang.patch: support -Xclang option
* Fri Nov  9 2012 idonmez@suse.com
- Implement %%check
- Don't install INSTALL.* files
* Sat Aug 11 2012 puzel@suse.com
- update to ccache-3.1.8
  - Made paths to dependency files relative in order to increase
    cache hits.
  - Added work-around to make ccache work with buggy GCC 4.1 when
    creating a pre-compiled header.
  - Clang plugins are now hashed to catch plugin upgrades.
  - Fixed crash when the current working directory has been
    removed.
  - Fixed crash when stderr is closed.
  - Corrected a corner case when parsing backslash escapes in
    string literals.
  - Paths are now correctly canonicalized when computing paths
    relative to the base directory.
  - Made git version macro work when compiling outside of the
    source directory.
  - Fixed `static_assert` macro definition clash with GCC 4.7.
* Mon Jan  9 2012 puzel@suse.com
- update to ccache-3.1.7
  - Non-writable `CCACHE_DIR` is now handled gracefully when
    `CCACHE_READONLY` is set.
  - Made failure to create files (typically due to bad directory
    permissions) in the cache directory fatal. Previously, such
    failures were silently and erroneously flagged as "compiler
    produced stdout".
  - Both the `-specs=file` and `--specs=file` forms are now
    recognized.
  - Added recognition and hashing of GCC plugins specified with
    `-fplugin=file`.
  - `CCACHE_COMPILERCHECK` now also determines how to hash explicit
    specs files (`-specs=file`).
  - Added `CPATH`, `C_INCLUDE_PATH` and similar environment
    variables to the hash to avoid false cache hits when such
    variables have changed.
  - Corrected log message when unify mode is enabled.
  - Reverted the GCC bug compatibility introduced in ccache 3.1.5
    for `-MT`/`-MQ` options with concatenated arguments. (The bug
    is fixed in recent GCC versions.)
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
* Sun Aug 21 2011 asterios.dramis@gmail.com
- update to ccache-3.1.6
  - Rewrite argument to --sysroot if CCACHE_BASEDIR is used.
  - Don't crash if getcwd() fails.
  - Fixed alignment of "called for preprocessing" counter.
* Mon Jun  6 2011 puzel@novell.com
- update to ccache-3.1.5
  - Added a new statistics counter named ``called for
    preprocessing''.
  - The original command line is now logged to the file specified
    with `CCACHE_LOGFILE`.
  - Improved error logging when system calls fail.
  - Added support for rewriting absolute paths in
    `-F`/`-iframework` GCC options.
  - Improved order of statistics counters in `ccache -s` output.
  - The `-MF`/`-MT`/`-MQ` options with concatenated argument are
    now handled correctly when they are last on the commandline.
  - ccache is now bug compatible with GCC for the `-MT`/`-MQ`
    options with concatenated arguments.
  - Fixed a minor memory leak.
  - Systems that lack (and don't need to be linked with) libm are
    now supported.
* Wed Feb 16 2011 asterios.dramis@gmail.com
- update to ccache-3.1.4
  - Made a work-around for a bug in gzputc() in zlib 1.2.5.
  - Corrupt manifest files are now removed so that they won't block direct
    mode hits.
  - ccache now copes with file systems that don't know about symbolic links.
  - The file handle in now correctly closed on write error when trying to
    create a cache dir tag.
- Spec file updates:
  - Changes based on rpmdevtools templates and spec-cleaner run.
  - Updated Summary: and %%description.
  - Made it compile with external zlib instead of the bundled copy.
  - Added also the html files in the %%doc section.
* Mon Nov 29 2010 puzel@novell.com
- update to ccache-3.1.3
  - The -MFarg, -MTarg and -MQarg compiler options (i.e, without
    space between option and argument) are now handled correctly.
* Mon Nov 22 2010 puzel@novell.com
- update to ccache-3.1.2
  - bail out on too hard compiler options '-fdump-*'
  - NULL return values from malloc/calloc of zero bytes are now
    handled correctly
  - improved documentation on which information is included in the
    hash sum
  - made the 'too new header file' test case work on file systems
    with unsynchronized clocks
  - the test suite now also works on systems that lack a /dev/zero
* Mon Nov  8 2010 puzel@novell.com
- update to ccache-3.1.1
  - ccache now falls back to preprocessor mode when a non-regular
    include file (device, socket, etc) has been detected so that
    potential hanging due to blocking reads is avoided.
  - CRC errors are now detected when decompressing compressed files
    in the cache.
  - Fixed potential object file corruption race on NFS.
  - Minor documentation corrections.
  - Fixed configure detection of ar.
  - ccache development version (set by dev.mk) now works with gits
    whose `describe` command doesn't understand `--dirty`.
* Fri Sep 17 2010 puzel@novell.com
- update to ccache-3.1
  - features:
  - Added support for hashing the output of a custom command
    (e.g. `$compiler --version`) to identify the compiler
    instead of stat-ing or hashing the compiler binary.
  - Added support for caching compilations that use precompiled
    headers.
  - Locking of the files containing statistics counters is now
    done using symlinks instead of POSIX locks.
  - Manifest files are now updated without the need of taking
    locks.
  - Added `.cp` and `.CP` as known C++ suffixes.
  - Improved logging.
  - bugfixes:
  - Non-fatal error messages are now never printed to stderr but
    logged instead.
  - Fixed a bug affecting failing commands when `--ccache-skip` is
    used.
  - Made `--ccache-skip` work for all options.
  - EINTR is now handled correctly.
* Fri Jul 16 2010 puzel@novell.com
- update to ccache-3.0.1
  - bugfixes:
  - The statistics counter ``called for link'' is now correctly
    updated when linking with a single object file.
  - Fixed a problem with out-of-source builds.
* Mon Jul 12 2010 puzel@novell.com
- update to ccache-3.0
  - notable changes:
  - The way the hashes are calculated has changed, so you won't get
  cache hits for compilation results stored by older ccache
  versions. Because of this, you might as well clear the old
  cache directory with `ccache --clear` if you want, unless you
  plan to keep using an older ccache version.
  - ccache now has a ``direct mode'' where it computes a hash of
  the source code (including all included files) and compiler
  options without running the preprocessor. By not running the
  preprocessor, CPU usage is reduced; the speed is somewhere
  between 1 and 5 times that of ccache running in traditional
  mode, depending on the circumstances. The speedup will be
  higher when I/O is fast (e.g., when files are in the disk
  cache).  The direct mode can be disabled by setting
  +CCACHE_NODIRECT+.
  - Support has been added for rewriting absolute paths to relative
  paths when hashing, in order to increase cache hit rate when
  building the same source code in different directories even
  when compiling with `-g` and when using absolute include
  directory paths. This is done by setting the `CCACHE_BASEDIR`
  environment variable to an absolute path that specifies which
  paths to rewrite.
  - Object files are now optionally stored compressed in the cache.
  The runtime cost is negligible, and more files will fit in the
  ccache directory and in the disk cache. Set `CCACHE_COMPRESS`
  to enable object file compression. Note that you can't use
  compression in combination with the hard link feature.
  - A `CCACHE_COMPILERCHECK` option has been added. This option
  tells ccache what compiler-identifying information to hash to
  ensure that results retrieved from the cache are accurate.
  Possible values are: none (don't hash anything), mtime (hash
  the compiler's mtime and size) and content (hash the content of
  the compiler binary). The default is mtime.
- see /usr/share/doc/packages/ccache/NEWS.txt for complete
  release notes
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Thu Sep 29 2005 dmueller@suse.de
- add norootforbuild
* Wed Sep 28 2005 dmueller@suse.de
- add norootforbuild
* Thu Oct 21 2004 ltinkl@suse.cz
- update to version 2.4
* Mon Sep 29 2003 ltinkl@suse.cz
- update to version 2.3
* Wed Jul  9 2003 ltinkl@suse.cz
- updated sources to version 2.2
* Fri Mar 28 2003 vbobek@suse.cz
- provides binary from older distcc package [#25806]
* Mon Feb 10 2003 vbobek@suse.cz
- initial suse release 2.1.1
